[![License](https://img.shields.io/badge/License-BSD_3--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)
![PyPI](https://img.shields.io/pypi/v/tar_dir_indexer)
[![tests](https://github.com/CeadeS/tar_dir_indexer/actions/workflows/tests.yml/badge.svg)](https://github.com/CeadeS/tar_dir_indexer/actions/workflows/tests.yml)
[![codecov](https://codecov.io/gh/CeadeS/tar_dir_indexer/branch/main/graph/badge.svg?token=1YT6TIS6MC)](https://codecov.io/gh/CeadeS/tar_dir_indexer)

# Indexer for directories containing tar nested tar files. 
